@@ -44,7 +44,7 @@
 #include "imports.h"
 #include "documents.h"
 #include "security.h"
-
+#include "pattern.h"
 
 
 /************************************************************************
@@ -107,7 +107,11 @@ xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
 	}
     }
 
-    import = xmlParseFile((const char *)URI);
+#ifdef XSLT_PARSE_OPTIONS
+    import = xmlReadFile((const char *) URI, NULL, XSLT_PARSE_OPTIONS);
+#else
+    import = xmlParseFile((const char *) URI);
+#endif
     if (import == NULL) {
 	xsltTransformError(NULL, style, cur,
 	    "xsl:import : unable to load %s\n", URI);
@@ -119,6 +123,8 @@ xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
 	res->parent = style;
 	res->next = style->imports;
 	style->imports = res;
+	xmlHashScan(res->templatesHash, 
+	            (xmlHashScanner) xsltNormalizeCompSteps, style);
 	style->extrasNr += res->extrasNr;
 	ret = 0;
     } else {
