@@ -199,7 +199,7 @@ xsltFreeCompMatchList(xsltCompMatchPtr comp) {
  * steps of an imported stylesheet.
  */
 void xsltNormalizeCompSteps(void *payload,
-        void *data, const xmlChar *name) {
+        void *data, const xmlChar *name ATTRIBUTE_UNUSED) {
     xsltCompMatchPtr comp = payload;
     xsltStylesheetPtr style = data;
     int ix;
@@ -656,7 +656,8 @@ xsltTestCompMatch(xsltTransformContextPtr ctxt, xsltCompMatchPtr comp,
 			    xmlXPathFreeObject(newlist);
 			    return(-1);
 			}
-			
+			index = 0;
+
 			if ((parent == NULL) || (node->doc == NULL))
 			    nocache = 1;
 			else {
@@ -666,6 +667,7 @@ xsltTestCompMatch(xsltTransformContextPtr ctxt, xsltCompMatchPtr comp,
 					     BAD_CAST " fake node libxslt")))
 				nocache = 1;
 			}
+			
 			if (nocache == 0) {
 			    if (list != NULL)
 				xmlXPathFreeObject(list);
@@ -675,6 +677,8 @@ xsltTestCompMatch(xsltTransformContextPtr ctxt, xsltCompMatchPtr comp,
 				(void *) list;
 			    XSLT_RUNTIME_EXTRA(ctxt, select->previousExtra) =
 				(void *) doc;
+			    XSLT_RUNTIME_EXTRA(ctxt, select->indexExtra) =
+			        0;
 			    XSLT_RUNTIME_EXTRA_FREE(ctxt, select->lenExtra) =
 				(xmlFreeFunc) xmlXPathFreeObject;
 			} else
@@ -732,11 +736,11 @@ xsltTestCompMatch(xsltTransformContextPtr ctxt, xsltCompMatchPtr comp,
 			while (sibling != NULL) {
 			    if (sibling == previous)
 				break;
-			    if ((node->type == XML_ELEMENT_NODE) &&
-				(node->name != NULL) &&
+			    if ((previous->type == XML_ELEMENT_NODE) &&
+				(previous->name != NULL) &&
 				(sibling->name != NULL) &&
-				(node->name[0] == sibling->name[0]) &&
-				(xmlStrEqual(node->name, sibling->name))) {
+				(previous->name[0] == sibling->name[0]) &&
+				(xmlStrEqual(previous->name, sibling->name))) {
 				if ((select->value2 == NULL) ||
 				    ((sibling->ns != NULL) &&
 				     (xmlStrEqual(select->value2,
