@@ -62,9 +62,15 @@ double xmlXPathStringEvalNumber(const xmlChar *str);
  * Useful macros
  */
 
+#ifdef  IS_BLANK
+#undef	IS_BLANK
+#endif
 #define IS_BLANK(c) (((c) == 0x20) || ((c) == 0x09) || ((c) == 0xA) ||	\
                      ((c) == 0x0D))
 
+#ifdef	IS_BLANK_NODE
+#undef	IS_BLANK_NODE
+#endif
 #define IS_BLANK_NODE(n)						\
     (((n)->type == XML_TEXT_NODE) && (xsltIsBlank((n)->content)))
 
@@ -1698,6 +1704,12 @@ xsltParseStylesheetTemplate(xsltStylesheetPtr style, xmlNodePtr template) {
 	    if (style != NULL) style->errors++;
 	    goto error;
 	} else {
+	    if (xmlValidateNCName(prop,0)) {
+	        xsltTransformError(NULL, style, template,
+	            "xsl:template : error invalid name '%s'\n", prop);
+		if (style != NULL) style->errors++;
+		goto error;
+	    } 
 	    ret->name = prop;
 	    if (URI != NULL)
 		ret->nameURI = xmlStrdup(URI);
@@ -2053,7 +2065,11 @@ xsltParseStylesheetFile(const xmlChar* filename) {
 	}
     }
 
+#ifdef XSLT_PARSE_OPTIONS
+    doc = xmlReadFile((const char *) filename, NULL, XSLT_PARSE_OPTIONS);
+#else
     doc = xmlParseFile((const char *) filename);
+#endif
     if (doc == NULL) {
 	xsltTransformError(NULL, NULL, NULL,
 		"xsltParseStylesheetFile : cannot parse %s\n", filename);
@@ -2248,6 +2264,14 @@ xsltLoadStylesheetPI(xmlDocPtr doc) {
 		subtree = ID->parent;
 		fake = xmlNewDoc(NULL);
 		if (fake != NULL) {
+#if LIBXML_VERSION >= 20600
+                    /*
+		     * the dictionnary should be shared since nodes are
+		     * moved over.
+		     */
+		    fake->dict = doc->dict;
+		    xmlDictReference(doc->dict);
+#endif
 		    xmlUnlinkNode(subtree);
 		    xmlAddChild((xmlNodePtr) fake, subtree);
 		    ret = xsltParseStylesheetDoc(fake);
