@@ -48,9 +48,7 @@
 
 #ifdef XSLT_NEED_TRIO
 #include "trio.h"
-#ifdef __VMS 
-# define vsnprintf trio_vsnprintf
-#endif
+#define vsnprintf trio_vsnprintf
 #endif
 
 /************************************************************************
@@ -417,18 +415,7 @@ xsltPrintErrorContext(xsltTransformContextPtr ctxt,
 
 	    file = doc->URL;
 	} else {
-	    /*
-	     * Try to find contextual informations to report
-	     */
-	    if (node->type == XML_ELEMENT_NODE) {
-		line = (int) node->content;
-	    } else if ((node->prev != NULL) &&
-		       (node->prev->type == XML_ELEMENT_NODE)) {
-		line = (int) node->prev->content;
-	    } else if ((node->parent != NULL) &&
-		       (node->parent->type == XML_ELEMENT_NODE)) {
-		line = (int) node->parent->content;
-	    }
+	    line = xmlGetLineNo(node);
 	    if ((node->doc != NULL) && (node->doc->URL != NULL))
 		file = node->doc->URL;
 	    if (node->name != NULL)
@@ -849,7 +836,17 @@ xsltDefaultSortFunction(xsltTransformContextPtr ctxt, xmlNodePtr *sorts,
 		    tst = 1;
 		else {
 		    if (number) {
-			if (results[j]->floatval == results[j + incr]->floatval)
+			/* We make NaN smaller than number in accordance
+			   with XSLT spec */
+			if (xmlXPathIsNaN(results[j]->floatval)) {
+			    if (xmlXPathIsNaN(results[j + incr]->floatval))
+				tst = 0;
+			    else
+				tst = -1;
+			} else if (xmlXPathIsNaN(results[j + incr]->floatval))
+			    tst = 1;
+			else if (results[j]->floatval ==
+				results[j + incr]->floatval)
 			    tst = 0;
 			else if (results[j]->floatval > 
 				results[j + incr]->floatval)
@@ -886,11 +883,24 @@ xsltDefaultSortFunction(xsltTransformContextPtr ctxt, xmlNodePtr *sorts,
 			res = resultsTab[depth];
 			if (res == NULL) 
 			    break;
-			if (res[j] == NULL)
-			    tst = 1;
-			else {
+			if (res[j] == NULL) {
+			    if (res[j+incr] != NULL)
+				tst = 1;
+			} else {
 			    if (numb) {
-				if (res[j]->floatval == res[j + incr]->floatval)
+				/* We make NaN smaller than number in
+				   accordance with XSLT spec */
+				if (xmlXPathIsNaN(res[j]->floatval)) {
+				    if (xmlXPathIsNaN(res[j +
+				    		incr]->floatval))
+					tst = 0;
+				    else
+				        tst = -1;
+				} else if (xmlXPathIsNaN(res[j + incr]->
+						floatval))
+				    tst = 1;
+				else if (res[j]->floatval == res[j + incr]->
+						floatval)
 				    tst = 0;
 				else if (res[j]->floatval > 
 					res[j + incr]->floatval)
@@ -1040,7 +1050,6 @@ int
 xsltSaveResultTo(xmlOutputBufferPtr buf, xmlDocPtr result,
 	       xsltStylesheetPtr style) {
     const xmlChar *encoding;
-    xmlNodePtr root;
     int base;
     const xmlChar *method;
     int indent;
@@ -1069,11 +1078,6 @@ xsltSaveResultTo(xmlOutputBufferPtr buf, xmlDocPtr result,
     if ((method == NULL) && (result->type == XML_HTML_DOCUMENT_NODE))
 	method = (const xmlChar *) "html";
 
-    if (method == NULL)
-	root = xmlDocGetRootElement(result);
-    else
-	root = NULL;
-
     if ((method != NULL) &&
 	(xmlStrEqual(method, (const xmlChar *) "html"))) {
 	if (encoding != NULL) {
@@ -1138,11 +1142,9 @@ xsltSaveResultTo(xmlOutputBufferPtr buf, xmlDocPtr result,
     } else {
 	int omitXmlDecl;
 	int standalone;
-	const xmlChar *version;
 
 	XSLT_GET_IMPORT_INT(omitXmlDecl, style, omitXmlDeclaration);
 	XSLT_GET_IMPORT_INT(standalone, style, standalone);
-	XSLT_GET_IMPORT_PTR(version, style, version)
 
 	if (omitXmlDecl != 1) {
 	    xmlOutputBufferWriteString(buf, "<?xml version=");
@@ -1612,7 +1614,7 @@ xsltGetProfileInformation(xsltTransformContextPtr ctxt)
     xsltStylesheetPtr style;
     xsltTemplatePtr *templates;
     xsltTemplatePtr templ;
-    int nb = 0, max = 0, i, j, total, totalt;
+    int nb = 0, max = 0, i, j;
 
     if (!ctxt)
         return NULL;
@@ -1667,8 +1669,6 @@ xsltGetProfileInformation(xsltTransformContextPtr ctxt)
     root = xmlNewDocNode(ret, NULL, BAD_CAST "profile", NULL);
     xmlDocSetRootElement(ret, root);
 
-    total = 0;
-    totalt = 0;
     for (i = 0; i < nb; i++) {
         child = xmlNewChild(root, NULL, BAD_CAST "template", NULL);
         sprintf(buf, "%d", i + 1);
@@ -1720,6 +1720,31 @@ static xsltDebuggerCallbacks xsltDebuggerCurrentCallbacks = {
 
 int xslDebugStatus;
 
+/**
+ * xsltSetDebuggerStatus:
+ * @value : the value to be set
+ * 
+ * This function sets the value of xslDebugStatus.
+ */
+void
+xsltSetDebuggerStatus(int value)
+{
+    xslDebugStatus = value;	
+}
+
+/**
+ * xsltGetDebuggerStatus: 
+ * 
+ * Get xslDebugStatus.
+ *
+ * Returns the value of xslDebugStatus.
+ */
+int
+xsltGetDebuggerStatus(void)
+{
+    return(xslDebugStatus);	
+}
+
 /**
  * xsltSetDebuggerCallbacks:
  * @no : number of callbacks
